import { LRParser, LocalTokenGroup } from '@lezer/lr';
import { styleTags, tags } from '@lezer/highlight';
import { LRLanguage, indentNodeProp, delimitedIndent, foldNodeProp, foldInside, LanguageSupport } from '@codemirror/language';

const highlighting = styleTags({
    String: tags.string,
    Number: tags.number,
    Boolean: tags.bool,
    Nil: tags.null,
    PropertyName: tags.propertyName,
    TemplateString: tags.string,
    "extern var const": tags.definitionKeyword,
    "include break continue enum class switch while for fork return": tags.keyword,
    "new": tags.special(tags.keyword),
    "List Map Set": tags.list,
    ",": tags.separator,
    "[ ]": tags.bracket,
    "{ }": tags.brace,
    "( ) |": tags.paren,
    '< <= > >= == "!="': tags.compareOperator,
    "if else and or": tags.logicOperator,
    '+ - "/" "*" "+=" "-=" "/=" "*="': tags.arithmeticOperator,
    Equal: tags.definitionOperator,
    DotDot: tags.arithmeticOperator,
    Comment: tags.lineComment,
    Choice: tags.controlOperator,
    BackUp: tags.controlOperator,
    BoughName: tags.controlKeyword,
    Speaker: tags.name,
    Tag: tags.tagName,
});

// This file was generated by lezer-generator. You probably shouldn't edit it.
const spec_identifier = {__proto__:null,include:8, and:30, or:32, if:70, else:72, new:80, List:92, Map:96, Set:104, fork:130, extern:140, var:142, const:144, for:148, while:152, switch:158, class:164, enum:168, return:172, break:176, continue:180};
const parser = LRParser.deserialize({
  version: 14,
  states: "N[QYQPOOO#]QPO'#EfO&eQPO'#CnO'cQPO'#CpOOQO'#Cz'#CzO(aQPO'#CxO)mQPO'#EvOOQO'#Ev'#EvOOQO'#Ej'#EjO+{OWO'#CaO,WQQO'#DfO,]QQO'#DiO,bQSO'#DkO,jQPO'#DqOOQO'#Ef'#EfOOQO'#EZ'#EZQYQPOOO&eQPO'#D{O(dQPO'#DTO,rQPO'#DZO,wQPO'#D]O,|QPO'#DaO#WQPO'#C_O-RQPO'#DnO(dQPO'#DsO-]QPO'#DsO-eQPO'#DwO&eQPO'#DyO'cQPO'#D|O(dQPO'#EPO(dQPO'#EROOQO'#ET'#ETOOQO'#EV'#EVOOQO'#EX'#EXOOQO'#Ce'#CeOOQO'#Cm'#CmO&eQPO,59OO'cQPO,59_O&eQPO,59bO&eQPO,59}OOQO'#Cj'#CjO.cQPO,59YO&eQPO'#DOO2xQPO,59[O3PQPO'#EqO3[QPO,59dO5bQPO,59dO5gQPO,59iO&eQPO,59mO5nQPO,59mO'cQPO'#CbOOOO'#E['#E[O5sOWO,58{OOQO,58{,58{O6OQPO,5:QOOQO,5:T,5:TO#WQPO,5:VO6VQPO,5:VO6OQPO,5:]O#WQPO,5:]OOQO-E8X-E8XO6[QPO,5:gO9^QPO,59oO9cQPO,59uO9jQPO,59wO9qQPO,59{OOQO,58y,58yO9xQPO'#EsOOQO'#Es'#EsOOQO,5:Y,5:YO6OQPO,5:YO:PQPO'#DROOQO,5:_,5:_O(dQPO,5:_O;cQPO,5:cO6[QPO,5:eO;jQPO,5:hO;qQPO,5:kO;vQPO,5:mP;{QPO,5:oO>YQPO1G.jO@bQPO1G.yOAvQPO1G.|OE]QPO1G/iOGeQPO,59jOOQO1G.v1G.vO(dQPO'#E]OI_QPO,5;]OOQO1G/O1G/OO3[QPO1G/OOIjQPO'#EtOOQO1G/T1G/TOIwQPO1G/TOLxQPO1G/XO&eQPO1G/XOM]QPO,58|OOOO-E8Y-E8YOOQO1G.g1G.gOOQO1G/l1G/lOMdQPO1G/qO#WQPO1G/qOOQO1G/w1G/wO6OQPO1G/wO!#sQPO'#CeO!#}QPO1G/UO!)`QPO1G0RO!)gQPO1G/ZOOQO1G/a1G/aO!)oQPO1G/aO!)tQPO'#D_O!){QPO'#EwOOQO1G/c1G/cO!*TQPO1G/cOOQO1G/g1G/gO!*YQPO1G/gOOQO,5;_,5;_O!*_QPO,5;_OOQO1G/t1G/tOOQO1G/y1G/yO(dQPO1G/}OOQO1G0P1G0PO!*fQPO1G0SO!*mQPO1G0VO!*rQPO1G0XOOQO7+$e7+$eO!*wQPO1G/UO!,rQPO'#ETOOQO,5:w,5:wOOQO-E8Z-E8ZOOQO,5:o,5:oOOQO7+$j7+$jO'cQPO'#E^O!-cQPO,5;`OOQO7+$o7+$oO!0jQPO7+$sOOOO'#De'#DeOOOO1G.h1G.hOOQO'#Ea'#EaO!0}QPO7+%]O!0}QPO7+%]OOQO7+%c7+%cO&eQPO7+$pO6OQPO7+%mO!4fQPO'#DVO!4kQPO'#EuOOQO7+$u7+$uO!4sQPO7+$uOOQO7+${7+${O'cQPO,59yO'cQPO'#E`O!4xQPO,5;cOOQO7+$}7+$}OOQO7+%R7+%ROOQO1G0y1G0yO!5QQPO7+%iO!5VQPO'#EOO!5^QPO'#EyO!5fQPO'#EOO!5kQPO7+%nO(dQPO7+%qO(dQPO7+%sO!5pQPO,5:xOOQO-E8[-E8[OOQO-E8_-E8_O!5}QPO<<HwO!9fQPO<<H[OOQO<<IX<<IXO'cQPO,59qO(dQPO'#E_O!<zQPO,5;aOOQO<<Ha<<HaO!=SQPO1G/eOOQO,5:z,5:zOOQO-E8^-E8^O6OQPO<<ITO!=^QPO,5:jO!*fQPO'#EbO!?dQPO,5;eOOQO<<IY<<IYO!?lQPO<<I]O!?qQPO<<I_O!?vQPO1G/]OOQO,5:y,5:yOOQO-E8]-E8]OOQOAN>oAN>oOOQO1G0U1G0UOOQO,5:|,5:|OOQO-E8`-E8`OOQOAN>wAN>wOOQOAN>yAN>yO!@QQPO'#EfO!@_QPO'#DnO!@fQPO'#DnO!BsQPO'#DnO!@mQPO,59dO3[QPO,5:QO!=^QPO,5:QO!@mQPO,5:QO3[QPO,5:]O!=^QPO,5:]O!@mQPO,5:]O!BzQPO,5:gO!E|QPO,5:gO!IOQPO,5:gO3[QPO,5:YO!=^QPO,5:YO!@mQPO,5:YO!BzQPO,5:eO!E|QPO,5:eO!IOQPO,5:eO!LQQPO,5:oO!@mQPO1G/OO!L_QPO1G/XO3[QPO1G/wO!=^QPO1G/wO!@mQPO1G/wO!LoQPO1G/UO!L|QPO'#ETO!MZQPO'#ETO!MhQPO7+$sO3[QPO7+%mO!=^QPO7+%mO!@mQPO7+%mO!MxQPO7+%mO3[QPO<<ITO!=^QPO<<ITO!@mQPO<<ITO!MxQPO<<ITO#!OQPO'#CxO#!WQQO'#DfO#!]QQO'#DfO#!bQQO'#DfO#!gQPO'#DqO#!oQPO'#DqO#!wQPO'#DqO&eQPO'#D{O&eQPO'#D{O&eQPO'#D{O&eQPO'#DyO&eQPO'#DyO&eQPO'#DyO'cQPO,59OO'cQPO,59bO'cQPO,59}O##PQPO,59dO'cQPO,59mO'cQPO,59mO&eQPO,59mO#WQPO,5:]O#WQPO,5:]O#WQPO,5:]O##UQPO'#DRO##gQPO'#DRO##xQPO'#DRO(dQPO,5:_O(dQPO,5:_O(dQPO,5:_O#$ZQPO1G.jO#$nQPO1G.|O#%RQPO1G/iO#&jQPO1G/XO'cQPO1G/XO'cQPO1G/XO&eQPO1G/XO#'QQPO1G/UO#'_QPO1G0RO#(eQPO1G0RO#)qQPO1G0RO#*[QPO1G0RO#+jQPO7+$sO'cQPO7+$pO#,QQPO7+%iO#,VQPO7+%iO#,[QPO7+%iO#,aQPO7+%iO#,fQPO'#EfO#-VQPO'#DnO!MxQPO,59dO!MxQPO,5:QO!MxQPO,5:]O#-^QPO,5:gO!MxQPO,5:YO#-^QPO,5:eO!MxQPO1G/OO#0`QPO1G/XO!MxQPO1G/wO#0mQPO1G/UO#1^QPO7+$sO#1kQPO'#EfO'cQPO'#CnO#1xQPO'#EvO(dQPO'#DsO(dQPO'#DsO(dQPO'#DsO#2fQPO'#DsO#2nQPO'#DsO#2vQPO'#DsO#3OQPO,59mO#3TQPO,59mO#3YQPO,59mO#3_QPO'#CeO(dQPO1G/}O(dQPO1G/}O(dQPO1G/}O(dQPO1G/}O#3iQPO1G/UO#3pQPO'#CxO#3xQQO'#DfO#3}QPO'#DqO&eQPO'#D{O&eQPO'#DyO-eQPO,59OO-eQPO,59bO-eQPO,59}O#4VQPO,59dO-eQPO,59mO#WQPO,5:]O#4[QPO'#DRO(dQPO,5:_O#4mQPO1G.jO#4}QPO1G.|O#5_QPO1G/iO#5oQPO1G/XO-eQPO1G/XO#5vQPO7+$sO-eQPO7+$pO#5}QPO'#EfO#6_QPO1G/UO#6oQPO,5:cO#6vQPO,5:cO#6}QPO,5:cO#7UQPO,5:cOGeQPO,59jO-eQPO'#CnO#7]QPO'#EvO(dQPO'#DsO#8]QPO'#DsO#8eQPO,59mO#8jQPO'#CeO#8tQPO1G/UO-eQPO'#DwO-eQPO'#DwO-eQPO'#DwO-eQPO'#DwO&eQPO'#DOOGeQPO,59jO&eQPO'#DO",
  stateData: "#9T~O#XOSPOS~OSfO]QOcQOeROmTOsaOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!ZYO!^ZO!cgO!f]O!hiO!ihO!jhO!ljO!nkO!qlO!tmO!vnO!xoO!zpO!|qO#ZSO#[XO~OYrOZrO[rO]rO_xO`xOhuOkvO!WwO#_sO#`sO#asO#bsO#csO#dsOS#YXc#YXe#YXm#YXs#YXx#YXz#YX{#YX|#YX!O#YX!Q#YX!S#YX!U#YX!Z#YX!^#YX!c#YX!f#YX!h#YX!i#YX!j#YX!l#YX!n#YX!q#YX!t#YX!v#YX!x#YX!z#YX!|#YX#V#YX#Z#YX#[#YXp#YXt#YX~O]QOcQOeROmTOszOxbOzVO{VO|VO!OcO!QdO!UeO#ZSO#[XO~O]']Oc']OeROm%|Os(fOxbOzVO{VO|VO!OcO!QdO!UeO#ZSO#[XO~Om}O#ZSO~Oe!PO_#jX`#jXh#jXk#jX!S#jX!W#jX#_#jX#`#jX#a#jX#b#jX#c#jX#d#jXo#jXt#jXp#jX~OY!ROZ!RO[!RO]!ROv!QOS#jXc#jXm#jXs#jXx#jXz#jX{#jX|#jX!O#jX!Q#jX!U#jX!Z#jX!^#jX!c#jX!f#jX!h#jX!i#jX!j#jX!l#jX!n#jX!q#jX!t#jX!v#jX!x#jX!z#jX!|#jX#V#jX#Z#jX#[#jX~P(iOV!SO#]!TO#l!VO~O![!WO~O![!XO~O!S!YO!`!ZO~OY!]O#[XO~Oo!aO~Oo!bO~Oo!cO~Oo!eO!d!hO~PYO!i!kO!j!kO~O](ZOc(ZOeROm'nOs(hOxbOzVO{VO|VO!OcO!QdO!UeO#ZSO#[XO~OhuOSbaYbaZba[ba]ba_ba`bacbaebakbambasbaxbazba{ba|ba!Oba!Qba!Sba!Uba!Wba!Zba!^ba!cba!fba!hba!iba!jba!lba!nba!qba!tba!vba!xba!zba!|ba#Vba#Zba#[ba#_ba#`ba#aba#bba#cba#dbafbaobaiba#fbapbatba~OYrOZrO[rO]rO_xO`xOhuOk&[O!W&]O#_sO#`sO#asO#bsO#csO#dsO~Of!wO~P1wO#f!xOm#eXp#eX~OSfO]QOcQOeROmTOo!eOs&TOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!Z%}O!^ZO!c%VO!f&QO!h'bO!i'_O!j'_O!l(bO!n&WO!qlO!tmO!vnO!xoO!zpO!|qO#ZSO#[XO~Om!{O~Of!}O~P'cOv#QO~OV!SO#]!TO#l#TO~Oo!eO~PYO!S#WO~OSfOYrOZrO[rO]#ZO_xO`xOcQOeROhuOkvOmTOo!eOsaOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!WwO!ZYO!^ZO!cgO!f]O!hiO!ihO!jhO!ljO!nkO!qlO!tmO!vnO!xoO!zpO!|qO#ZSO#[XO#_sO#`sO#asO#bsO#csO#dsO~Oo#^O~Op#_O~P'cOp#cO~P'cOp#eO~P'cOp#gO~PYOY'gOZ'gO['gO]'gOv&aO~OYrOZrO[rO]rO_xO`xOhuOk'tO!W'uO#_sO#`sO#asO#bsO#csO#dsO~Om#kO~P:bOo#mO~P1wOv#nO~Ov#oO~OYrOZrO[rO_xO`xOhuOkvO!WwO#_sO#`sO#asO#bsO#csO#dsO~Q!waYrOZrO[rO]rO_xO`xOhuO#_sO#`sO#asO#bsO#csO#dsOkWi!SWi!WWioWitWipWi~OkvO!WwOSWicWieWimWisWixWizWi{Wi|Wi!OWi!QWi!UWi!ZWi!^Wi!cWi!fWi!hWi!iWi!jWi!lWi!nWi!qWi!tWi!vWi!xWi!zWi!|Wi#VWi#ZWi#[Wi~P<{Oi#pO~P1wOYrOZrO[rO]rO_xO`xOhuO#_sO#`sO#asO#bsO#csO#dsOkji!Sji!Wjiojitjipji~OkvO!WwOSjicjiejimjisjixjizji{ji|ji!Oji!Qji!Uji!Zji!^ji!cji!fji!hji!iji!jji!lji!nji!qji!tji!vji!xji!zji!|ji#Vji#Zji#[ji~P@iOYrOZrO[rO]rO_xO`xOhuO#_sO#`sO#asO#bsO#csO#dsOk!Vi!S!Vi!W!Vio!Vit!Vip!Vi~OkvO!WwOS!Vic!Vie!Vim!Vis!Vix!Viz!Vi{!Vi|!Vi!O!Vi!Q!Vi!U!Vi!Z!Vi!^!Vi!c!Vi!f!Vi!h!Vi!i!Vi!j!Vi!l!Vi!n!Vi!q!Vi!t!Vi!v!Vi!x!Vi!z!Vi!|!Vi#V!Vi#Z!Vi#[!Vi~PDOOYrOZrO[rO]'hO_xO`xOc']OeROhuOkvOm%|Os(fOxbOzVO{VO|VO!OcO!QdO!UeO!WwO#ZSO#[XO#_sO#`sO#asO#bsO#csO#dsO~O#f!xOm#eap#ea~O#f#wOf#hXp#hX~P1wOf#yO~OYrOZrO[rO]rOhuO#_sO#`sO#asO#bsO#csO#dsOSuicuieuimuisuixuizui{ui|ui!Oui!Qui!Sui!Uui!Zui!^ui!cui!fui!hui!iui!jui!lui!nui!qui!tui!vui!xui!zui!|ui#Vui#Zui#[uituipui~O_ui`uikui!Wuioui~PI|Op#{O~P1wO!a#}OS!_i]!_ic!_ie!_im!_is!_ix!_iz!_i{!_i|!_i!O!_i!Q!_i!S!_i!U!_i!Z!_i!^!_i!c!_i!f!_i!h!_i!i!_i!j!_i!l!_i!n!_i!q!_i!t!_i!v!_i!x!_i!z!_i!|!_i#V!_i#Z!_i#[!_iY!_iZ!_i[!_i_!_i`!_ih!_ik!_i!W!_i#_!_i#`!_i#a!_i#b!_i#c!_i#d!_it!_ip!_if!_io!_ii!_i#f!_i~OeXXmXXsXXxXXzXX{XX|XX!OXX!QXX!UXX#ZXX#[XX~O]QOcQO~P!!{OYrOZrO[rO]rO_xO`xOhuOkvOt$RO!WwO#_sO#`sO#asO#bsO#csO#dsOS#YXc#YXe#YXm#YXs#YXx#YXz#YX{#YX|#YX!O#YX!Q#YX!S#YX!U#YX!Z#YX!^#YX!c#YX!f#YX!h#YX!i#YX!j#YX!l#YX!n#YX!q#YX!t#YX!v#YX!x#YX!z#YX!|#YX#V#YX#Z#YX#[#YXp#YX~OS!oi]!oic!oie!oim!ois!oix!oiz!oi{!oi|!oi!O!oi!Q!oi!S!oi!U!oi!Z!oi!^!oi!c!oi!f!oi!h!oi!i!oi!j!oi!l!oi!n!oi!q!oi!t!oi!v!oi!x!oi!z!oi!|!oi#V!oi#Z!oi#[!oip!oi~Ot$SO~P!'VOp$VO#ZSO~Op$XO~O!S$YO~P1wO#f$ZOp#kX~Op$]O~Op$^O~Op$_O~PYOt$cO~P'cOo$eO~Oo$fO~Ot$RO~P1wOeROxbOzVO{VO|VO!OcO!QdO!UeO#ZSO#[XOY!wXZ!wX[!wX]!wX_!wX`!wXh!wXk!wX!W!wX#_!wX#`!wX#a!wX#b!wX#c!wX#d!wXt!wX~Oc']Om%|Os(fOf!wXo!wXi!wX#f!wXp!wX!S!wX~P!+OO#f#wOf#hap#ha~OYrOZrO[rO]rOhuO#_sO#`sO#asO#bsO#csO#dsOSuqcuqeuqmuqsuqxuqzuq{uq|uq!Ouq!Quq!Suq!Uuq!Zuq!^uq!cuq!fuq!huq!iuq!juq!luq!nuq!quq!tuq!vuq!xuq!zuq!|uq#Vuq#Zuq#[uqtuqpuq~O_uq`uqkuq!Wuqouq~P!-nO!a#}OS!_q]!_qc!_qe!_qm!_qs!_qx!_qz!_q{!_q|!_q!O!_q!Q!_q!S!_q!U!_q!Z!_q!^!_q!c!_q!f!_q!h!_q!i!_q!j!_q!l!_q!n!_q!q!_q!t!_q!v!_q!x!_q!z!_q!|!_q#V!_q#Z!_q#[!_qY!_qZ!_q[!_q_!_q`!_qh!_qk!_q!W!_q#_!_q#`!_q#a!_q#b!_q#c!_q#d!_qt!_qp!_qf!_qo!_qi!_q#f!_q~Ov$mO~O#f$nOp#iX~Op$pO~O#f$ZOp#ka~Om$tO~O!S$uO~P1wO#f$vOp#mX~O!S$uO~Op$xO~Of#Qa#f#Qap#Qa~P1wO!a#}OS!_y]!_yc!_ye!_ym!_ys!_yx!_yz!_y{!_y|!_y!O!_y!Q!_y!S!_y!U!_y!Z!_y!^!_y!c!_y!f!_y!h!_y!i!_y!j!_y!l!_y!n!_y!q!_y!t!_y!v!_y!x!_y!z!_y!|!_y#V!_y#Z!_y#[!_yY!_yZ!_y[!_y_!_y`!_yh!_yk!_y!W!_y#_!_y#`!_y#a!_y#b!_y#c!_y#d!_yt!_yp!_yf!_yo!_yi!_y#f!_y~OhuOSryYryZry[ry]ry_ry`rycryerykrymrysryxryzry{ry|ry!Ory!Qry!Sry!Ury!Wry!Zry!^ry!cry!fry!hry!iry!jry!lry!nry!qry!try!vry!xry!zry!|ry#Vry#Zry#[ry#_ry#`ry#ary#bry#cry#dryfryoryiry#fryprytry~O#f$nOp#ia~Op!Ri#f!Ri~P1wOSfO]']Oc']OeROm%|Oo!eOs&UOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!Z&OO!^ZO!c%WO!f&RO!h'cO!i'`O!j'`O!l(cO!n&XO!qlO!tmO!vnO!x%rO!zpO!|qO#ZSO#[XO~O#f$vOp#ma~Op%SO~Op%TO~Opyi#fyi~P1wOk#YX!W#YXo#YX~P#]O!d%dO~P3[O!d%eO~P!=^OSfO]']Oc']OeROm%|Oo!eOs&VOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!Z&PO!^ZO!c%XO!f&SO!h'dO!i'aO!j'aO!l(dO!n&YO!qlO!tmO!vnO!x#rO!zpO!|qO#ZSO#[XO~O!d%fO~P!@mOSfOYrOZrO[rO]#ZO_xO`xOcQOeROhuOkvOmTOo!eOs&TOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!WwO!Z%}O!^ZO!c%VO!f&QO!h'bO!i'_O!j'_O!l(bO!n&WO!qlO!tmO!vnO!xoO!zpO!|qO#ZSO#[XO#_sO#`sO#asO#bsO#csO#dsO~OSfOYrOZrO[rO]'hO_xO`xOc']OeROhuOkvOm%|Oo!eOs&UOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!WwO!Z&OO!^ZO!c%WO!f&RO!h'cO!i'`O!j'`O!l(cO!n&XO!qlO!tmO!vnO!x%rO!zpO!|qO#ZSO#[XO#_sO#`sO#asO#bsO#csO#dsO~OSfOYrOZrO[rO]'hO_xO`xOc']OeROhuOkvOm%|Oo!eOs&VOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!WwO!Z&PO!^ZO!c%XO!f&SO!h'dO!i'aO!j'aO!l(dO!n&YO!qlO!tmO!vnO!x#rO!zpO!|qO#ZSO#[XO#_sO#`sO#asO#bsO#csO#dsO~Op!wa#f!wat!wa~P1wO_xO`xOkvO!WwO~PI|Ok#YX!W#YXo#YX~P!#}Oc(ZOs(hOm!wX~P!+OOp!wX#f!wXt!wX~P'cO_xO`xOkvO!WwO~P!-nOSfO](ZOc(ZOeROm'nOo!eOs'qOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!Z'oO!^ZO!c'OO!f'pO!h(^O!i(]O!j(]O!l(eO!n'rO!qlO!tmO!vnO!x%qO!zpO!|qO#ZSO#[XO~Om%YO#ZSO~O![%ZO~O![%[O~O![%]O~OY&bO#[XO~OY&cO#[XO~OY&dO#[XO~Om%kO~OY!ROZ!RO[!RO]!ROv!QO~OY'fOZ'fO['fO]'fOv&`O~OY'eOZ'eO['eO]'eOv&_O~Ok&[O!W&]OfWiiWi#fWi~P<{Ok&[O!W&]Ofjiiji#fji~P@iOk&[O!W&]Of!Vii!Vi#f!Vi~PDOOYrOZrO[rO]rOhuO#_sO#`sO#asO#bsO#csO#dsO_ui`uikui!Wuitui~Ofuiouiiui#fuipui!Sui~P#%fOt&xOp#YX#f#YX~P1wOt%tOY!oiZ!oi[!oi_!oi`!oih!oik!oi!W!oi#_!oi#`!oi#a!oi#b!oi#c!oi#d!oio!oi~P!'VOt%uOp!oi#f!oi~OY!oiZ!oi[!oi]!oi_!oi`!oih!oik!oi!W!oi#_!oi#`!oi#a!oi#b!oi#c!oi#d!oi~Ot%vOf!oio!oii!oi#f!oip!oi!S!oi~P#(pOt%wOm!oi~P#(pOYrOZrO[rO]rOhuO#_sO#`sO#asO#bsO#csO#dsO_uq`uqkuq!Wuqtuq~Ofuqouqiuq#fuqpuq!Suq~P#*fOm%xO~Om%yO~Om%zO~Om%{O~Of#YXk#YX!W#YXo#YXi#YX#f#YXp#YX!S#YXt#YX~P1wO!d'TO~P!MxOSfOYrOZrO[rO](`O_xO`xOc(ZOeROhuOkvOm'nOo!eOs'qOxbOzVO{VO|VO!OcO!QdO!S[O!UeO!WwO!Z'oO!^ZO!c'OO!f'pO!h(^O!i(]O!j(]O!l(eO!n'rO!qlO!tmO!vnO!x%qO!zpO!|qO#ZSO#[XO#_sO#`sO#asO#bsO#csO#dsO~Opui#fuitui~P1wOt&xOf#YXk#YX!W#YXo#YXi#YX#f#YXp#YX!S#YX~P1wOpuq#fuqtuq~P1wOp#YX#f#YXt#YX~P1wOY'eOZ'eO['eO]'eOv&_Of#jXi#jX#f#jX~P(iO!i&hO!j&hO~O!i&iO!j&iO~O!i&jO!j&jO~Ov&oO~Ov&pO~Ov&qO~O]']Oc']O~P!!{Ot&xO~P1wOm'PO#ZSO~O!['QO~OY'xO#[XO~Om'VO~OY(_OZ(_O[(_O](_Ov'wO~OkWimWi!WWitWi~P:bOkjimji!Wjitji~P:bOk!Vim!Vi!W!Vit!Vi~P:bOmui~P#%fOmuq~P#*fOk#YXm#YX!W#YXt#YX~P:bOt(ROk#YXm#YX!W#YX~P:bOm'iO~P:bOm'jO~P:bOm'kO~P:bOm'lO~P:bOe!PO_#jX`#jXh#jXk#jXm#jX!W#jX#_#jX#`#jX#a#jX#b#jX#c#jX#d#jXt#jX~P#4[O!i'zO!j'zO~Ov(PO~O](ZOc(ZO~P!!{Ot(RO~P1wOz{PZ!`#Z#X~",
  goto: "Jf#nPPP#oP${(cP(g+XPPPP,oPP+X(gP.PPP(gPP(gP0nP3[PP.P.PPP7ZP.PP:WPPP:_P:_P<|P:_P=SP?t#oPP#oP#oPP#oPP#oP#oPPP#oP#oP#o#oP?w#oP#oP#oP#oP#oP?}@X@_@e@k@q@wARPPPAXPPPBgPPPPPPG{PHXJPJY(gJ`PJc#e^O`g}!W![!_!e!h!m!{#Y#h$S$t$u%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%t%u%v%w%x%y%z%{'O'P'Q'R'S'T'U'V'X&WVOQR`agjkltuvwz}!P!Q!S!W![!_!a!b!c!e!h!m!v!{#Q#Y#h#m#r#w$R$S$Y$Z$m$t$u$v%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%q%r%t%u%v%w%x%y%z%{&T&U&V&W&X&Y&Z&[&]&_&`&a&o&p&q&x'O'P'Q'R'S'T'U'V'X']'q'r's't'u'w(P(R(Y(Z(b(c(d(e(f(g(hQ![]Q!dfQ#V!YQ#Y!]Q$P#WQ%^&QQ%_&RQ%`&SQ%m&bQ%n&cQ%o&dQ'R'pR'X'xT!TX!U&_WOQR`agjkltuvwz}!P!Q!S!W![!_!a!b!c!e!h!m!v!{#Q#Y#Z#h#m#r#w$R$S$Y$Z$m$t$u$v%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%q%r%t%u%v%w%x%y%z%{&T&U&V&W&X&Y&Z&[&]&_&`&a&o&p&q&x'O'P'Q'R'S'T'U'V'X']'h'q'r's't'u'w(P(R(Y(Z(`(b(c(d(e(f(g(h!StP!_!m!q!r!t!u!v#P#[#z%U%a%b%c%g%h%i%l%p%s'S'U(Y(g!S&Z{!n!s!|#R#a#q$a$g$q${%j&k&l&m&n&r&w&}'W'Y'Z'['m(ai's!l'{'|'}(O(Q(S(T(U(V(W(X!OtP!_!m!q!r!t!u!v#[%U%a%b%c%g%h%i%l%p%s'S'U(Y(g!O&Z{!n!s!|#R#a#q$a$g$q${%j&k&l&m&r&}'W'Y'Z'['m(ae's!l'{'|'}(S(T(U(V(W(X&XWOQR`agjkltuvwz}!P!Q!S!W![!_!a!b!c!e!h!m!v!{#Q#Y#h#m#r#w$R$S$Y$Z$m$t$u$v%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%q%r%t%u%v%w%x%y%z%{&T&U&V&W&X&Y&Z&[&]&_&`&a&o&p&q&x'O'P'Q'R'S'T'U'V'X']'q'r's't'u'w(P(R(Y(Z(b(c(d(e(f(g(h&VWOQR`agjkltuvwz}!P!Q!S!W![!_!a!b!c!e!h!m!v!{#Q#Y#h#m#r#w$R$S$Y$Z$m$t$u$v%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%r%t%u%v%w%x%y%z%{&T&U&V&W&X&Y&Z&[&]&_&`&a&o&p&q&x'O'P'Q'R'S'T'U'V'X']'q'r's't'u'w(P(R(Y(Z(b(c(d(e(f(g(h#OUOQ`agktvwz}!Q!W![!_!e!h!m!{#Q#Y#h$R$S$t%V%Z%^%a%d%g%m%t%x&T&U&V&W&X&Y&a&q'q'r(f(hW|T$f%|'nQ!`bS!ih!kQ!omQ!pnQ#s!xU$T#^$e$nQ$`#kS&e&h'_S&f&i'`S&g&j'aQ&y'iQ&z'jQ&{'kQ&|'l#U'^Rlu!P!S!a!b!c!v#m#r#w$Y$Z$m$u$v%W%X%Y%[%]%_%`%b%c%e%f%h%i%k%n%o%r%u%v%y%z&Z&[&]&_&`&o&p&x'](Y(gS'y'z(]!R([j%q%w%{'O'P'Q'R'S'T'U'V'X's't'u'w(P(R(Z(b(c(d(e&WWOQR`agjkltuvwz}!P!Q!S!W![!_!a!b!c!e!h!m!v!{#Q#Y#h#m#r#w$R$S$Y$Z$m$t$u$v%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%q%r%t%u%v%w%x%y%z%{&T&U&V&W&X&Y&Z&[&]&_&`&a&o&p&q&x'O'P'Q'R'S'T'U'V'X']'q'r's't'u'w(P(R(Y(Z(b(c(d(e(f(g(hY!jh'_'`'a(]Z#j!k&h&i&j'zS$U#^$eR$|$n&XVOQR`agjkltuvwz}!P!Q!S!W![!_!a!b!c!e!h!m!v!{#Q#Y#h#m#r#w$R$S$Y$Z$m$t$u$v%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%q%r%t%u%v%w%x%y%z%{&T&U&V&W&X&Y&Z&[&]&_&`&a&o&p&q&x'O'P'Q'R'S'T'U'V'X']'q'r's't'u'w(P(R(Y(Z(b(c(d(e(f(g(hQ#b!bR$r$Z&_VOQR`agjkltuvwz}!P!Q!S!W![!_!a!b!c!e!h!m!v!{#Q#Y#Z#h#m#r#w$R$S$Y$Z$m$t$u$v%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%q%r%t%u%v%w%x%y%z%{&T&U&V&W&X&Y&Z&[&]&_&`&a&o&p&q&x'O'P'Q'R'S'T'U'V'X']'h'q'r's't'u'w(P(R(Y(Z(`(b(c(d(e(f(g(hR#|#RQ$b#mR%Q$vQ`OS!^`#hR#h!eQ!UXR#S!UQ!y|R#t!yQ#x!|R$h#xQ$o$UR$}$oQ$[#bR$s$[Q$O#VS$i$O$jR$j$PQ$w$bR%R$wW_O`!e#h#]!fg}!W![!_!h!m!{#Y$S$t$u%V%W%X%Y%Z%[%]%^%_%`%a%b%c%d%e%f%g%h%i%k%m%n%o%t%u%v%w%x%y%z%{'O'P'Q'R'S'T'U'V'XhPO`g!W![!e!h!m#Y#h$S$t[yQ#Z']'h(Z(`Q{RQ!_aQ!ljQ!mkQ!nlQ!rtQ!suQ!tvQ!uwQ!vzU!|!P!a!cQ#P!QQ#R!SQ#[!_S#a!b$ZQ#q!vS#u#r%qQ#z#QS$a#m$vQ$g#wU$k$R&x(RQ$q$YQ${$md%U}!{%V%Z%^%d%g%m%t%xQ%a&TQ%b&UQ%c&VQ%g&WQ%h&XQ%i&YQ%j%rQ%l&aQ%p%aQ%s&qQ&k&ZQ&l&[Q&m&]Q&n&_Q&r%bQ&w&od&}%X%Y%]%`%f%i%k%o%v%zQ'S'qQ'U'rQ'W&`Q'Y%cQ'Z&pb'[$u%W%[%_%e%h%n%u%yQ'm(YQ'{'sQ'|'tQ'}'uQ(O'wQ(Q(Pd(S%w%{'O'P'Q'R'T'U'V'XQ(T'SQ(U(bQ(V(cQ(W(dQ(X(eQ(Y(fQ(a(gR(g(hQ!OTQ$z$fQ&^%|R'v'nY!gg%V%W%X'OU!z}%Y'PY#U!W%Z%[%]'QY#X![%^%_%`'RQ#]!_Y#i!h%d%e%f'TY#l!m%g%h%i'UU#v!{%k'VY$Q#Y%m%n%o'XY$l$S%t%u%v%wY%O$t%x%y%z%{Q%P$uQ&s%aQ&t%bQ&u%cR&v'SQ#O!PQ#`!aR#f!cQ$W#^R$y$eR#d!bR$d#m",
  nodeNames: "⚠ Comment Program IncludeStatement include TemplateString Interpolation InterpolationStart Binary ArithOp * / + - LogicOp and or CompareOp Unary ! Group ( ) Index [ ] Member . Function | Identifier { } Call If if else Assign Equal Instance new Field Boolean Nil Number List List Map Map MapPair : Set Set Range DotDot InterpolationEnd BoughStatement Bough BoughName DivertStatement Jump DialogueStatement Speaker Tag ForkStatement fork BackUp ChoiceStatement Choice VariableStatement extern var const ForStatement for WhileStatement while IfStatement SwitchStatement switch Prong ClassStatement class EnumStatement enum Return return Break break Continue continue",
  maxTerm: 121,
  nodeProps: [
    ["isolate", -3,1,5,6,""],
    ["closedBy", 7,"InterpolationEnd"],
    ["openedBy", 55,"InterpolationStart"]
  ],
  propSources: [highlighting],
  skippedNodes: [0,1],
  repeatNodeCount: 8,
  tokenData: "Gb~R!ROX$[XY$yYZ$yZ]$[]^$y^p$[pq$yqr%drs&nst'Xtu)Sux$[xy*byz*{z{+f{|,P|},j}!O-T!O!P-n!P!Q.u!Q!R/f!R![1U![!]1r!]!^$[!^!_1w!_!`3R!`!a5j!a!c$[!c!})S!}#O6t#P#Q7_#Q#R7x#R#S)S#S#T$[#T#Y)S#Y#Z8c#Z#b)S#b#c>t#c#h)S#h#iBl#i#o)S#o#pEY#p#qEs#q#rF^#r#sFw#s$g$[$g;'S)S;'S;=`*[<%lO)SW$aU!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[W$vP;=`<%l$[~%QU!`W#X~O!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y%kWcQ!`WO!P$[!Q![$[!]!_$[!_!`&T!`#O$[#P;'S$[;'S;=`$s<%lO$[Y&[U#`Q!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y&uU#[Q!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y'`_!aQ!`WOY'XYZ$[Zs'Xst$[t!P'X!P!Q(_!Q!['X![!](_!]#O'X#O#P(_#P#k'X#k#l$[#l;'S'X;'S;=`(|<%lO'XQ(dU!aQOY(_Zs(_t#k(_#l;'S(_;'S;=`(v<%lO(_Q(yP;=`<%l(_Y)PP;=`<%l'X^)]_![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^*_P;=`<%l)SY*iUeQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y+SUfQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y+mUYQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y,WU[Q!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y,qU#fQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y-[U]Q!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y-uVkQ!`WO!O$[!O!P.[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y.cU!WQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[~.zPZ~!P!Q.}~/SSP~OY.}Z;'S.};'S;=`/`<%lO.}~/cP;=`<%l.}Y/mV|Q!`WO!O$[!O!P0S!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y0XU!`WO!P$[!Q![0k!]#O$[#P;'S$[;'S;=`$s<%lO$[Y0rU|Q!`WO!P$[!Q![0k!]#O$[#P;'S$[;'S;=`$s<%lO$[Y1]V|Q!`WO!O$[!O!P0S!Q![1U!]#O$[#P;'S$[;'S;=`$s<%lO$[~1wO!S~Y2OW#aQ!`WO!P$[!Q![$[!]!_$[!_!`2h!`#O$[#P;'S$[;'S;=`$s<%lO$[Y2oU#cQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y3YXvQ!`WO!P$[!Q![$[!]!_$[!_!`3u!`!a5P!a#O$[#P;'S$[;'S;=`$s<%lO$[Y3|W#_Q!`WO!P$[!Q![$[!]!_$[!_!`4f!`#O$[#P;'S$[;'S;=`$s<%lO$[Y4mU!ZQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y5WU!^Q!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y5qW#bQ!`WO!P$[!Q![$[!]!_$[!_!`6Z!`#O$[#P;'S$[;'S;=`$s<%lO$[Y6bU#dQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y6{UhQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y7fUiQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[Y8PU!dQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[^8l`![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#U9n#U#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^9wa![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#`)S#`#a:|#a#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^;Va![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#g)S#g#h<[#h#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^<ea![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#X)S#X#Y=j#Y#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^=u_![SzQ!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^>}a![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#])S#]#^@S#^#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^@]a![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#`)S#`#aAb#a#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^Am_![S{Q!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^Bua![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#f)S#f#gCz#g#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)S^DTa![S!`W#ZQOt$[tu)Su!P$[!Q![)S!]!c$[!c!})S!}#O$[#P#R$[#R#S)S#S#T$[#T#i)S#i#j<[#j#o)S#o$g$[$g;'S)S;'S;=`*[<%lO)SYEaUoQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[YEzUmQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[YFeUpQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[YGOU!fQ!`WO!P$[!Q![$[!]#O$[#P;'S$[;'S;=`$s<%lO$[",
  tokenizers: [1, 2, 3, new LocalTokenGroup("d~RQrsX#o#p^~^O#l~~cOV~~", 19, 105)],
  topRules: {"Program":[0,2]},
  specialized: [{term: 103, get: (value) => spec_identifier[value] || -1}],
  tokenPrec: 5333
});

const topiLanguage = LRLanguage.define({
    parser: parser.configure({
        props: [
            indentNodeProp.add({
                Application: delimitedIndent({ closing: ")", align: false })
            }),
            foldNodeProp.add({
                Application: foldInside
            }),
            highlighting
        ]
    }),
    languageData: {
        commentTokens: { line: "//" }
    }
});
function topi() {
    return new LanguageSupport(topiLanguage);
}

export { topi, topiLanguage };
